.. image:: https://readthedocs.org/projects/loam/badge/?version=latest
   :target: http://loam.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://badge.fury.io/py/loam.svg
   :target: https://badge.fury.io/py/loam
   :alt: PyPI version

loam
====

The main goal of loam is to offer a light and simple interface to manage the
configuration of your own Python application. It avoids you the burden of
writing the code to build the command line argument parser and/or a
configuration file parser in a self-consistent way.
